@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="pl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
 <context>
     <name>KWin::MultitaskViewEffect</name>
     <message>
@@ -12,4 +10,4 @@
         <translation>Brak okien</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
