@@ -35,7 +35,6 @@
 #include "workspace.h"
 #include "useractions.h"
 #include "wayland/dderestrict_interface.h"
-#include "scene/surfaceitem.h"
 
 #include <KDecoration2/DecoratedClient>
 #include <KDecoration2/Decoration>
@@ -257,8 +256,6 @@ static QRectF gravitateGeometry(const QRectF &rect, const QRectF &bounds, Gravit
 
 void XdgSurfaceV6Window::handleNextWindowGeometry()
 {
-    const QRectF boundingGeometry = surface()->boundingRect();
-
     // The effective window geometry is defined as the intersection of the window geometry
     // and the rectangle that bounds the main surface and all of its sub-surfaces. If the
     // client hasn't specified the window geometry, we must fallback to the bounding geometry.
@@ -266,10 +263,13 @@ void XdgSurfaceV6Window::handleNextWindowGeometry()
     // window geometry.
 
     m_windowGeometry = m_shellSurface->windowGeometry();
-    if (m_windowGeometry.isValid()) {
-        m_windowGeometry &= boundingGeometry;
-    } else {
-        m_windowGeometry = boundingGeometry;
+    if (surface()->viewportExtension()) {
+        const QRectF boundingGeometry = surface()->boundingRect();
+        if (m_windowGeometry.isValid()) {
+            m_windowGeometry &= boundingGeometry;
+        } else {
+            m_windowGeometry = boundingGeometry;
+        }
     }
 
     if (m_windowGeometry.isEmpty()) {
@@ -1786,9 +1786,6 @@ void XdgToplevelV6Window::updateMaximizeMode(MaximizeMode maximizeMode)
     setMaximized(maximizeMode & MaximizeHorizontal && maximizeMode & MaximizeVertical);
     Q_EMIT clientMaximizedStateChanged(this, maximizeMode);
     Q_EMIT clientMaximizedStateChanged(this, maximizeMode & MaximizeHorizontal, maximizeMode & MaximizeVertical);
-    if (maximizeMode == MaximizeFull || maximizeMode == MaximizeRestore)
-        Q_EMIT clientMaximizedChanged(this, m_restoreMaxiArea, frameGeometry(), maximizeMode);
-
 }
 
 void XdgToplevelV6Window::updateFullScreenMode(bool set)
@@ -2028,10 +2025,6 @@ void XdgToplevelV6Window::maximize(MaximizeMode mode, bool animated)
     if (m_requestedMaximizeMode == mode) {
         return;
     }
-    if (auto item = surfaceItem()) {
-        item->discardPixmap();
-    }
-    m_restoreMaxiArea = frameGeometry();
     Q_EMIT clientMaximizedStateAboutToChange(this, mode);
     m_requestedMaximizeMode = mode;
 
